@@ -55,6 +55,36 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelCreateBatchCancelFlowUrl(self, request):
+        """指定需要批量撤回的签署流程Id，获取批量撤销链接
+        客户指定需要撤回的签署流程Id，最多100个，超过100不处理；接口调用成功返回批量撤回合同的链接，通过链接跳转到电子签小程序完成批量撤回
+
+        :param request: Request instance for ChannelCreateBatchCancelFlowUrl.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBatchCancelFlowUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreateBatchCancelFlowUrl", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ChannelCreateBatchCancelFlowUrlResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ChannelCreateFlowByFiles(self, request):
         """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口不可直接使用，需要运营申请
 
@@ -202,7 +232,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateSignUrls(self, request):
-        """创建参与者签署短链
+        """创建跳转小程序查看或签署的链接；自动签署的签署方不创建签署链接；
 
         :param request: Request instance for CreateSignUrls.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsRequest`
@@ -260,8 +290,7 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeResourceUrlsByFlows(self, request):
-        """根据签署流程信息批量获取资源下载链接，可直接下载
-        限制：只能下载合作企业授权过的、单方签署的签署流程文件（若合作企业与渠道是同一企业，可以下载所有签署流程文件）
+        """根据签署流程信息批量获取资源下载链接，需合作企业先进行授权
 
         :param request: Request instance for DescribeResourceUrlsByFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeResourceUrlsByFlowsRequest`
